@@ -1,5 +1,5 @@
 /* *************************************************************************
- *  Copyright 2012 Jakob Gruber <jakob.gruber@gmail.com>                   *
+ *  Copyright 2015 Jakob Gruber <jakob.gruber@gmail.com>                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
  *  it under the terms of the GNU General Public License as published by   *
@@ -18,7 +18,7 @@
 #ifndef SELECTBOARD_H
 #define SELECTBOARD_H
 
-#include <kdialog.h>
+#include <QDialog>
 #include <QSharedPointer>
 
 #include "ui_selectboardwindow.h"
@@ -26,7 +26,7 @@
 class Level;
 class LevelTableModel;
 
-class SelectBoardWindow : public KDialog
+class SelectBoardWindow : public QDialog
 {
     Q_OBJECT
 public:
