@@ -1,5 +1,5 @@
 /*
-    Copyright 2012 Jakob Gruber <jakob.gruber@gmail.com>
+    Copyright 2015 Jakob Gruber <jakob.gruber@gmail.com>
     Copyright 2011 Julian Helfferich <julian.helfferich@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
@@ -19,15 +19,14 @@
 #include "config.h"
 #include "levelloader.h"
 
+#include <KLocalizedString>
 #include <QDebug>
 #include <QDir>
 #include <QDomDocument>
 #include <QFile>
-#include <QSettings>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
+#include <QStandardPaths>
 
+#include "src/settings.h"
 #include "src/systemexception.h"
 
 class LevelList : public QList<QSharedPointer<Level> >
@@ -83,11 +82,11 @@ QString Level::key() const {
 }
 
 void Level::writeSettings(int seconds) {
-    QSettings settings;
+    QSharedPointer<QSettings> settings = Settings::instance()->qSettings();
     QString k = key();
 
-    settings.setValue(k, seconds);
-    settings.sync();
+    settings->setValue(k, seconds);
+    settings->sync();
 }
 
 void Level::finalize() {
@@ -96,12 +95,12 @@ void Level::finalize() {
 }
 
 void Level::readSettings() {
-    QSettings settings;
+    QSharedPointer<QSettings> settings = Settings::instance()->qSettings();
     QString k = key();
 
-    if (settings.contains(k)) {
+    if (settings->contains(k)) {
         m_solved = true;
-        m_solved_time = settings.value(k).toInt();
+        m_solved_time = settings->value(k).toInt();
     }
 }
 
@@ -138,7 +137,9 @@ QList<QSharedPointer<Level> > LevelLoader::load() {
     QList<QString> paths;
     paths << QString(prefix)
           << QString(FILEPATH "/" + prefix)
-          << KGlobal::dirs()->findResourceDir("appdata", prefix) + prefix;
+          << QStandardPaths::locate(QStandardPaths::AppDataLocation,
+                                    prefix,
+                                    QStandardPaths::LocateOption::LocateDirectory);
 
     LevelList list;
 
@@ -261,7 +262,7 @@ QSharedPointer<Level> LevelLoader::loadLevel(const QDomElement &node) const {
 }
 
 static Board::State charToState(const QChar &c) {
-    switch (c.toAscii()) {
+    switch (c.toLatin1()) {
     case '-': return Board::Nothing;
     case '1': return Board::Box;
     default: throw SystemException("Invalid char in level definition");
